# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litepie/slider/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litepie\\Slider\\": "packages/litepie/slider/src",
            "Litepie\\Slider\\Seeders\\": "packages/litepie/slider/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litepie\Slider\Providers\SliderServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Slider'  => Litepie\Slider\Facades\Slider::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litepie\\Slider\\Seeders\\SliderTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litepie\Slider\Providers\SliderServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litepie\Slider\Providers\SliderServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litepie\Slider\Providers\SliderServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/slider/{modulename}

**User**

    http://path-to-route-folder/user/slider/{modulename}

**Public**

    http://path-to-route-folder/sliders


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/slider/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/slider/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/slider/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/slider/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/slider/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/slider/{modulename}/{slug}
    METHOD: GET